@@ -70,11 +70,10 @@ AdaBoostModel <- function(boos = TRUE, mfinal = 100,
     design = "terms",
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
-      data <- model.frame(formula, data)
-      formula[[2]] <- formula(data)[[2]]
-      adabag::boosting(formula, data = data, ...)
+      adabag::boosting(formula, data = as.data.frame(data), ...)
     },
     predict = function(object, newdata, ...) {
+      newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata)$prob
     },
     varimp = function(object, ...) {
