@@ -22,9 +22,13 @@ grid <- function(x, ...) {
 }
 
 
-grid.formula <- function(x, data, model, length = 3, random = FALSE, ...) {
-  ModelFrame(x, data, na.action = na.pass) %>%
-    grid(model, length = length, random = random)
+grid.formula <- function(x, data, ...) {
+  grid(ModelFrame(x, data, na.rm = FALSE), ...)
+}
+
+
+grid.matrix <- function(x, y, ...) {
+  grid(ModelFrame(x, y, na.rm = FALSE), ...)
 }
 
 
@@ -43,7 +47,6 @@ grid.ModelFrame <- function(x, model, length = 3, random = FALSE, ...) {
 }
 
 
-grid.recipe <- function(x, model, length = 3, random = FALSE, ...) {
-  ModelFrame(x, na.action = na.pass) %>%
-    grid(model, length = length, random = random)
+grid.recipe <- function(x, ...) {
+  grid(ModelFrame(x, na.rm = FALSE), ...)
 }
