@@ -5,6 +5,64 @@
 #' cutoff probabilities.  Available curves include receiver operating
 #' characteristic (ROC) and precision recall.
 #' 
+#' @name performance_curve
+#' @rdname performance_curve
+#' 
+#' @param ... named or unnamed \code{performance_curve} output to combine
+#' together with the \code{Curves} constructor.
+#' 
+Curves <- function(...) {
+  .Curves(...)
+}
+
+
+.Curves <- function(..., .metrics = list()) {
+  args <- list(...)
+  
+  if (length(args) == 0) stop("no performance_curve output given")
+  
+  .Data <- args[[1]]
+  if (all(mapply(is, args, "Curves"))) {
+    
+    metrics <- .Data@metrics
+    if (!all(sapply(args, function(x) identical(x@metrics, metrics)))) {
+      stop("Curves arguments have different metrics")
+    }
+
+  } else if (length(args) > 1) {
+    
+    stop("arguments to combine must be Curves objects")
+    
+  } else if (!is.data.frame(.Data)) {
+    
+    stop("Curves argument must inherit from data.frame")
+    
+  } else {
+    
+    if (!all(mapply(is, .metrics[1:2], "MLMetric"))) {
+      stop("missing performance metrics in Curves constructor")
+    }
+    metrics <- c(y = .metrics[[1]], x = .metrics[[2]])
+
+    var_names <- c("Cutoff", "x", "y")
+    is_missing <- !(var_names %in% names(.Data))
+    if (any(is_missing)) {
+      stop("missing performance curve variables: ",
+           toString(var_names[is_missing]))
+    }
+    
+    decreasing <- !xor(metrics$x@maximize, metrics$y@maximize)
+    sort_order <- order(.Data$x, .Data$y, decreasing = c(FALSE, decreasing),
+                        method = "radix")
+    args[[1]] <- .Data[sort_order, , drop = FALSE]
+
+  }
+
+  args <- make_unique_levels(args, which = "Model")
+  new("Curves", do.call(append, args), metrics = metrics)
+}
+
+
 #' @rdname performance_curve
 #' 
 #' @param x observed responses or \code{Resamples} object of observed and
@@ -70,7 +128,12 @@ performance_curve.Resamples <- function(x, metrics = c(MachineShop::tpr,
 #' 
 performance_curve.default <- function(x, y, metrics = c(MachineShop::tpr,
                                                         MachineShop::fpr),
-                                      ...) {
+                                      na.rm = TRUE, ...) {
+  if (na.rm) {
+    complete <- complete_subset(x = x, y = y)
+    x <- complete$x
+    y <- complete$y
+  }
   .curve(x, y, metrics = .get_curve_metrics(metrics))
 }
 
@@ -131,7 +194,7 @@ setMethod(".curve_default", c("factor", "numeric"),
 
 setMethod(".curve_default", c("Surv", "SurvProbs"),
   function(observed, predicted, metrics, ...) {
-    times <- predicted@times
+    times <- time(predicted)
     surv <- predict(survfit(observed ~ 1, se.fit = FALSE), times)
 
     conf <- ConfusionMatrix(table(Predicted = 0:1, Observed = 0:1))
@@ -141,7 +204,7 @@ setMethod(".curve_default", c("Surv", "SurvProbs"),
         
         time <- times[i]
         surv_all <- surv[i]
-        pred <- predicted[, i]
+        pred <- predicted[, i, drop = TRUE]
         
         cutoffs <- c(-Inf, unique(pred))
         x <- y <- numeric(length(cutoffs))
